@@ -308,10 +308,12 @@ class Model(object):
         elif self.status == EDITABLE:
             published = self._version(PUBLISHED_UNDER_EDIT)
             published._create_edit_copy_onto(self)
+            self._revert_related()
             return self
         elif self.status == UPDATABLE:
             published = self._version(PUBLISHED_UNDER_UPDATE)
             published._create_update_copy_onto(self)
+            self._revert_related()
             return self
         elif self.status == DELETED:
             published = self._version(PUBLISHED_UNDER_DELETE)
@@ -535,16 +537,13 @@ class Model(object):
         result.status = EDITABLE
         # this has to be done *after* the basic properties of result
         # are set otherwise relations don't get set up properly
-        for prop in self._get_relation_props(ONETOMANY):
-            orig_values = getattr(self, prop.key)
-            values = getattr(result, prop.key)
-            for related in orig_values[:]:
-                #if related.status in NEW_VERSION_STATUSES:
-                #    orig_values.remove(related)
-                #    values.append(related)
-                if related.status == PUBLISHED:
-                    values.append(related._create_edit_cpy())
-                    related.status = PUBLISHED_UNDER_EDIT
+#         for prop in self._get_relation_props(ONETOMANY):
+#             orig_values = getattr(self, prop.key)
+#             values = getattr(result, prop.key)
+#             for related in orig_values[:]:
+#                 if related.status == PUBLISHED:
+#                     values.append(related._create_edit_copy())
+#                     related.status = PUBLISHED_UNDER_EDIT
         return result
         
     def _move_relations(self, source):
