@@ -896,7 +896,7 @@ class ClioTestCase(unittest.TestCase):
         self.session.flush()
         self.assertEquals(clio.PUBLISHED, one_reverted.bs[0].status)
 
-    def test_a_rel_revert_cursive_deleted_editable(self):
+    def test_a_rel_revert_recursive_deleted_editable(self):
         one = self._get_rel_published()
         one_editable = one.edit()
         self.assertEquals(clio.EDITABLE, one_editable.bs[0].status)
@@ -905,7 +905,16 @@ class ClioTestCase(unittest.TestCase):
         self.session.flush()
         self.assertEquals(2, len(list(one_reverted.bs)))
         self.assertEquals(clio.EDITABLE, one_reverted.bs[0].status)
-        
+
+    def test_a_rel_revert_recursive_new(self):
+        one = self._get_rel_published()
+        one_editable = one.edit()
+        new_b = B(b_code(self.session), u"New")
+        one_editable.bs.append(new_b)
+        one_reverted = one_editable.revert()
+        self.session.flush()
+        self.assertEquals(2, len(list(one_reverted.bs)))
+
     def test_one_to_many_relation_edit(self):
         """We adding relations to a previously published object.
         """
